@@ -18,20 +18,24 @@ class ConfigError(ValueError):
 class Config(object):
   """Configuration object"""
   def __init__(self):
-    self._opts = {}
+    self.opts = {}
+
+  def get(self, k, default=None):
+    return self.opts.get(k, default)
 
   def load_from_file(self, path):
     """Load options from a file."""
-    if not os.path.exists(path):
-      pass
-    else:
-      opts = yaml.load(path)
-      self.load_from(opts)
+    if os.path.exists(path):
+      with open(path) as f:
+        opts = yaml.load(f)
+        self.load_from(opts)
 
   def load_from(self, opts):
     """Load options from a dict-like or list of pairs."""
+    if not opts:
+      return
     try:
-      self._opts.update(opts)
+      self.opts.update(opts)
     except ValueError:
       raise ConfigError('Options are not a k/v map.')
 
@@ -43,6 +47,7 @@ class InstanceDirectory(object):
     self.user_path = user_path
     self.create()
     self.config_path = self.path('config.yaml')
+    self.shortcuts_path = self.path('shortcuts.yaml')
 
   def create(self):
     if not os.path.exists(self.user_path):
@@ -54,4 +59,9 @@ class InstanceDirectory(object):
   def load_config(self):
     config = Config()
     config.load_from_file(self.config_path)
-    
+    return config
+
+  def load_shortcuts(self):
+    config = Config()
+    config.load_from_file(self.shortcuts_path)
+    return config
